#include <iostream>

using namespace std;

class Time
{
  public:
    Time();   // default constructor
    Time( int newHours, int newMinutes ); // explicit constructor
    int getHours() const; // constant method
    int getMinutes() const;
    void setHours( int newHours );
    void setMinutes( int newMinutes );
    void print() const;
    void enter();
    void read( istream& in );
    void write( ostream& out ) const;
    void add( const Time& time );
    bool equal( const Time& time ) const;
    bool lessThan( const Time& time ) const;

  private:
    int hours;
    int minutes;
};

Time::Time()
{
  hours = 0;
  minutes = 0;
}

Time::Time( int newHours, int newMinutes )
{
  setHours( 0 );
  setMinutes( 0 );
  setHours( newHours );
  setMinutes( newMinutes );
}

void Time::enter()
{
  int newHours, newMinutes;
  char ch;
  cin >> newHours >> ch >> newMinutes;
  if ( ch == ':' ) {
    setHours( newHours );
    setMinutes( newMinutes );
  } // if
}

int Time::getHours() const
{
  return hours;
}

int Time::getMinutes() const
{
  return minutes;
}

void Time::print() const
{
  if ( hours < 10 )
    cout << '0';
  cout << hours;
  cout << ':';
  if ( minutes < 10 )
    cout << '0';
  cout << minutes << endl;
}

void Time::read( istream& in )
{
  in >> hours >> minutes;
}

void Time::setHours( int newHours )
{
  if ( newHours >= 0 && newHours <= 23 )
    hours = newHours;
}

void Time::setMinutes( int newMinutes )
{
  if ( newMinutes >= 0 && newMinutes <= 59 )
    minutes = newMinutes;
}

void Time::write( ostream& out ) const
{
  out << hours << ' ' << minutes;
}

void Time::add( const Time& time )
{
  minutes += time.minutes;
  if ( minutes > 59 ) {
    hours += 1;
    minutes = 60 - minutes;
  }
  hours += time.hours;
  if ( hours > 23 )
    hours = 24 - hours;
}

bool Time::equal( const Time& time ) const
{
  return ( hours == time.hours && minutes == time.minutes );
}

bool Time::lessThan( const Time& time ) const
{
  if ( hours < time.hours )
    return true;
  if ( hours == time.hours && minutes < time.minutes )
    return true;
  return false;
}

int main()
{
  Time t1( 5, 12 );
  Time t2( 5, 15 );
  if ( t1.lessThan( t2 ) )
    cout << "less than!" << endl;
  else
    cout << "not less than!" << endl;
  return 0;
}
