#include <iostream>

using namespace std;

class Time
{
  friend ostream& operator<<( ostream& out, const Time& time );
  friend istream& operator>>( istream& in, Time& time );

  public:
    Time();   // default constructor
    Time( int newHours, int newMinutes ); // explicit constructor
    int getHours() const; // constant method
    int getMinutes() const;
    void setHours( int newHours );
    void setMinutes( int newMinutes );
    void print() const;
    void enter();
    void read( istream& in );
    void write( ostream& out ) const;
    void add( const Time& time );
    bool equal( const Time& time ) const;
    bool lessThan( const Time& time ) const;
    void operator+=( const Time& time );
    bool operator==( const Time& time ) const;
    bool operator<( const Time& time ) const;

  private:
    int hours;
    int minutes;
};

Time::Time()
{
  hours = 0;
  minutes = 0;
}

Time::Time( int newHours, int newMinutes )
{
  setHours( 0 );
  setMinutes( 0 );
  setHours( newHours );
  setMinutes( newMinutes );
}

void Time::enter()
{
  int newHours, newMinutes;
  char ch;
  cin >> newHours >> ch >> newMinutes;
  if ( ch == ':' ) {
    setHours( newHours );
    setMinutes( newMinutes );
  } // if
}

int Time::getHours() const
{
  return hours;
}

int Time::getMinutes() const
{
  return minutes;
}

void Time::print() const
{
  if ( hours < 10 )
    cout << '0';
  cout << hours;
  cout << ':';
  if ( minutes < 10 )
    cout << '0';
  cout << minutes << endl;
}

void Time::read( istream& in )
{
  in >> hours >> minutes;
}

void Time::setHours( int newHours )
{
  if ( newHours >= 0 && newHours <= 23 )
    hours = newHours;
}

void Time::setMinutes( int newMinutes )
{
  if ( newMinutes >= 0 && newMinutes <= 59 )
    minutes = newMinutes;
}

void Time::write( ostream& out ) const
{
  out << hours << ' ' << minutes;
}

void Time::add( const Time& time )
{
  minutes += time.minutes;
  if ( minutes > 59 ) {
    hours += 1;
    minutes = 60 - minutes;
  }
  hours += time.hours;
  if ( hours > 23 )
    hours = 24 - hours;
}

bool Time::equal( const Time& time ) const
{
  return ( hours == time.hours && minutes == time.minutes );
}

bool Time::lessThan( const Time& time ) const
{
  if ( hours < time.hours )
    return true;
  if ( hours == time.hours && minutes < time.minutes )
    return true;
  return false;
}

void Time::operator+=( const Time& time )
{
  add( time );
}

bool Time::operator==( const Time& time ) const
{
  return equal( time );
}

bool Time::operator<( const Time& time ) const
{
  return lessThan( time );
}

ostream& operator<<( ostream& out, const Time& time )
{
  if ( time.hours < 10 )
    out << '0';
  out << time.hours;
  out << ':';
  if ( time.minutes < 10 )
    out << '0';
  out << time.minutes;
  return out;
}

istream& operator>>( istream& in, Time& time )
{
  int newHours, newMinutes;
  char ch;
  in >> newHours >> ch >> newMinutes;
  if ( ch == ':' ) {
    time.setHours( newHours );
    time.setMinutes( newMinutes );
  } // if
  return in;
}

int main()
{
  Time t1( 7, 12 );
  cout << t1 << endl;
  Time t2( t1 ); // copy constructor
  cout << t2 << endl;
  Time t3 = t1;
  cout << t3 << endl;
  Time t4( 15, 32 );
  cout << t4 << endl;
  t4 = t1;
  cout << t4 << endl;
  return 0;
}
