#include <iostream>

using namespace std;

class Time
{
  friend ostream& operator<<( ostream& out, const Time& time );
  friend istream& operator>>( istream& in, Time& time );

  public:
    Time();   // default constructor
    Time( int newHours, int newMinutes ); // explicit constructor
    int getHours() const; // constant method
    int getMinutes() const;
    void setHours( int newHours );
    void setMinutes( int newMinutes );
    void print( ostream& out = cout ) const;
    void println( ostream& out = cout ) const;
    void enter( istream& in = cin );
    void read( istream& in );
    void write( ostream& out ) const;
    void add( const Time& time );
    bool equal( const Time& time ) const;
    bool lessThan( const Time& time ) const;
    void operator+=( const Time& time );
    bool operator==( const Time& time ) const;
    bool operator<( const Time& time ) const;

    static const int maxHours = 24;
    static const int maxMinutes = 60;
    static const Time noon;

  private:
    int hours;
    int minutes;
};

const Time Time::noon( 12, 0 );

Time::Time()
{
  hours = 0;
  minutes = 0;
}

Time::Time( int newHours, int newMinutes )
{
  setHours( 0 );
  setMinutes( 0 );
  setHours( newHours );
  setMinutes( newMinutes );
}

void Time::enter( istream& in )
{
  int newHours, newMinutes;
  char ch;
  in >> newHours >> ch >> newMinutes;
  if ( in && ch == ':' ) {
    setHours( newHours );
    setMinutes( newMinutes );
  } // if
}

int Time::getHours() const
{
  return hours;
}

int Time::getMinutes() const
{
  return minutes;
}

void Time::print( ostream& out ) const
{
  if ( hours < 10 )
    out << '0';
  out << hours;
  out << ':';
  if ( minutes < 10 )
    out << '0';
  out << minutes;
}

void Time::println( ostream& out ) const
{
  print();
  out << endl;
}

void Time::read( istream& in )
{
  in >> hours >> minutes;
}

void Time::setHours( int newHours )
{
  if ( newHours >= 0 && newHours <= 23 )
    hours = newHours;
}

void Time::setMinutes( int newMinutes )
{
  if ( newMinutes >= 0 && newMinutes <= 59 )
    minutes = newMinutes;
}

void Time::write( ostream& out ) const
{
  out << hours << ' ' << minutes;
}

void Time::add( const Time& time )
{
  minutes += time.minutes;
  if ( minutes > 59 ) {
    hours += 1;
    minutes = 60 - minutes;
  }
  hours += time.hours;
  if ( hours > 23 )
    hours = 24 - hours;
}

bool Time::equal( const Time& time ) const
{
  return ( hours == time.hours && minutes == time.minutes );
}

bool Time::lessThan( const Time& time ) const
{
  if ( hours < time.hours )
    return true;
  if ( hours == time.hours && minutes < time.minutes )
    return true;
  return false;
}

void Time::operator+=( const Time& time )
{
  add( time );
}

bool Time::operator==( const Time& time ) const
{
  return equal( time );
}

bool Time::operator<( const Time& time ) const
{
  return lessThan( time );
}

ostream& operator<<( ostream& out, const Time& time )
{
  time.print( out );
  return out;
}

istream& operator>>( istream& in, Time& time )
{
  time.enter( in );
  return in;
}

int main()
{
  cout << Time::maxHours << endl;
  cout << Time::maxMinutes << endl;
	cout << Time::noon << endl;
  return 0;
}
